/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef __RND_ERROR_CODES__
#define __RND_ERROR_CODES__

#include <blberr.h>

#define RND_INVALID_TIME 0xe0000200
#define RND_NULL_SERVER_NAME 0xe0000201
#define RND_ALREADY_CONNECTED 0xe0000202
#define RND_NOT_CONNECTED 0xe0000203

#endif
