/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _MS_STOCK_PROP_PAGES_H_
#define _MS_STOCK_PROP_PAGES_H_

DEFINE_GUID(CLSID_StockFontPage,0x7ebdaae0,0x8120,0x11cf,0x89,0x9f,0x0,0xaa,0x0,0x68,0x8b,0x10);
DEFINE_GUID(CLSID_StockColorPage,0x7ebdaae1,0x8120,0x11cf,0x89,0x9f,0x0,0xaa,0x0,0x68,0x8b,0x10);
DEFINE_GUID(CLSID_StockPicturePage,0x7ebdaae2,0x8120,0x11cf,0x89,0x9f,0x0,0xaa,0x0,0x68,0x8b,0x10);

#endif
