/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define FTPWPP_ERROR_FIRST __MSABI_LONG(0x40042300)
#define FTPWPP_ERROR_INETOPEN_FAILED __MSABI_LONG(0xC0042301)
#define FTPWPP_ERROR_AUTHENTICATION_FAILED __MSABI_LONG(0xC0042302)
#define FTPWPP_ERROR_LAST __MSABI_LONG(0x400423FF)
