/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _LM_
#define _LM_

#include <lmcons.h>
#include <lmerr.h>

#include <lmaccess.h>
#include <lmalert.h>
#include <lmshare.h>
#include <lmmsg.h>
#include <lmremutl.h>
#include <lmrepl.h>
#include <lmserver.h>
#include <lmsvc.h>
#include <lmuse.h>
#include <lmwksta.h>
#include <lmapibuf.h>
#include <lmerrlog.h>
#include <lmconfig.h>
#include <lmstats.h>
#include <lmaudit.h>
#include <lmjoin.h>
#endif
