/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _INC_CPLEXT
#define _INC_CPLEXT

#define CPLPAGE_MOUSE_BUTTONS 1
#define CPLPAGE_MOUSE_PTRMOTION 2
#define CPLPAGE_MOUSE_WHEEL 3

#define CPLPAGE_KEYBOARD_SPEED 1

#define CPLPAGE_DISPLAY_BACKGROUND 1

#endif
