/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#define DISPID_LOAD 1
#define DISPID_UNLOAD 2
#define DISPID_SUBMIT 3
#define DISPID_FOCUS 4
#define DISPID_CHANGE 5
#define DISPID_BLUR 6
#define DISPID_SELECT 7
#define DISPID_MOUSEOVER 8
#define DISPID_PARSECOMPLETE 9
#define DISPID_ABORT 10
#define DISPID_ERROR 11
#define DISPID_MOUSEOUT 12
