/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */

#ifndef _WRL_H_
#define _WRL_H_

#include <wrl/client.h>
/* #include <wrl/implements.h> */
#include <wrl/module.h>
/* #include <wrl/event.h> */

#endif
