/**
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER within this package.
 */
#if !(defined(lint) || defined(RC_INVOKED))
#pragma pack(1)
#endif
