/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
/*
    File: strings.h
    Copyright: Public Domain

    This file is provided because non ANSI fuctions are described in string.h 
    that belong in strings.h.  These functions are provided for in the OLDNAME
    libraries.
*/
#ifndef _STRINGS_H_
#define _STRINGS_H_ 1
#include <string.h>
#endif
