/**
 * This file has no copyright assigned and is placed in the Public Domain.
 * This file is part of the mingw-w64 runtime package.
 * No warranty is given; refer to the file DISCLAIMER.PD within this package.
 */
#ifndef _LMUSEFLG_
#define _LMUSEFLG_

#define USE_NOFORCE 0
#define USE_FORCE 1
#define USE_LOTS_OF_FORCE 2

#endif
